summaryrefslogtreecommitdiffstats
path: root/device/bluetooth/bluetooth_socket_win.h
diff options
context:
space:
mode:
authorisherman@chromium.org <isherman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-07-03 06:08:20 +0000
committerisherman@chromium.org <isherman@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2014-07-03 06:08:20 +0000
commitdbedd502b4ad7d87364117713b2fcbab137b8a7b (patch)
tree8ff67d6d5f212f0eabb2585dce68e682f34abbfd /device/bluetooth/bluetooth_socket_win.h
parent9bca91a385fc635927347c2e6b0ce4da1eaa0df5 (diff)
downloadchromium_src-dbedd502b4ad7d87364117713b2fcbab137b8a7b.zip
chromium_src-dbedd502b4ad7d87364117713b2fcbab137b8a7b.tar.gz
chromium_src-dbedd502b4ad7d87364117713b2fcbab137b8a7b.tar.bz2
Use name passed to chrome.bluetoothSocket.create() as the SDP service name for listening sockets.
If no name is passed, then don't register a name for the SDP service. BUG=385946 TEST=Optional name passed to chrome.bluetoothSocket.create() is registered in the system SDP server when listening. R=keybuk@chromium.org Review URL: https://codereview.chromium.org/346443003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@281179 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'device/bluetooth/bluetooth_socket_win.h')
-rw-r--r--device/bluetooth/bluetooth_socket_win.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/device/bluetooth/bluetooth_socket_win.h b/device/bluetooth/bluetooth_socket_win.h
index 22ec412..59fec08 100644
--- a/device/bluetooth/bluetooth_socket_win.h
+++ b/device/bluetooth/bluetooth_socket_win.h
@@ -10,6 +10,7 @@
#include <string>
#include "base/memory/ref_counted.h"
+#include "device/bluetooth/bluetooth_adapter.h"
#include "device/bluetooth/bluetooth_service_record_win.h"
#include "device/bluetooth/bluetooth_socket.h"
#include "device/bluetooth/bluetooth_socket_net.h"
@@ -41,12 +42,13 @@ class BluetoothSocketWin : public BluetoothSocketNet {
const ErrorCompletionCallback& error_callback);
// Listens using this socket using an RFCOMM service published as UUID |uuid|
// with Channel |channel|. |success_callback| will be called if the service
// is successfully registered, |error_callback| on failure with a message
// explaining the cause.
void Listen(scoped_refptr<BluetoothAdapter> adapter,
const BluetoothUUID& uuid,
- int rfcomm_channel,
+ const BluetoothAdapter::ServiceOptions& options,
const base::Closure& success_callback,
const ErrorCompletionCallback& error_callback);
@@ -41,12 +42,13 @@ class BluetoothSocketWin : public BluetoothSocketNet {
const ErrorCompletionCallback& error_callback);
// Listens using this socket using an RFCOMM service published as UUID |uuid|
- // with Channel |channel|. |success_callback| will be called if the service
+ // with Channel |options.channel|, or an automatically allocated Channel if
+ // |options.channel| is null. |success_callback| will be called if the service
// is successfully registered, |error_callback| on failure with a message
// explaining the cause.